//
//  CuadradoView.swift
//  Cuadrado Hueco Variable
//
//  Created by Santiago Pavón Gómez on 19/9/16.
//  Copyright © 2016 UPM. All rights reserved.
//

import UIKit

@IBDesignable
class CuadradoView: UIView {

    @IBInspectable
    var size: Double = 100.0 {
        didSet {
            setNeedsDisplay()
        }
    }
    
    @IBInspectable
    var hole: Bool = false {
        didSet {
            setNeedsDisplay()
        }
    }
    
    @IBInspectable
    var fillColor: UIColor = UIColor.red {
        didSet {
            setNeedsDisplay()
        }
    }
    
    override func awakeFromNib() {
        addGestureRecognizer(UIPinchGestureRecognizer(target: self, action: #selector(CuadradoView.pinch(_:))))
        addGestureRecognizer(UIRotationGestureRecognizer(target: self, action: #selector(CuadradoView.rotate(_:))))
        addGestureRecognizer(UITapGestureRecognizer(target: self, action: #selector(CuadradoView.tap(_:))))
        
    }
    
    func pinch(_ sender:UIPinchGestureRecognizer) {
        let scale = sender.scale
        transform = transform.scaledBy(x: scale, y: scale)
        //size *= scale
        sender.scale = 1
    }
    
    
    func rotate(_ sender:UIRotationGestureRecognizer) {
        transform = transform.rotated(by: sender.rotation)
        sender.rotation = 0
    }
    
    func tap(_ sender:UITapGestureRecognizer) {
        hole = !hole
    }
    

    
    override func draw(_ rect: CGRect)
    {
        let rect = CGRect(
            x: bounds.size.width/2 - CGFloat(size/2),
            y: bounds.size.height/2 - CGFloat(size/2),
            width: CGFloat(size),
            height: CGFloat(size))
        let path = UIBezierPath(roundedRect: rect, cornerRadius: CGFloat(size/20))
        
        if hole {
            let rect2 = CGRect(
                x: bounds.size.width/2 - CGFloat(size/4),
                y: bounds.size.height/2 - CGFloat(size/4),
                width: CGFloat(size/2),
                height: CGFloat(size/2))
            let path2 = UIBezierPath(roundedRect: rect2, cornerRadius: CGFloat(size/40))
            
            path.usesEvenOddFillRule = true
            path.append(path2)
        }
        
        UIColor.blue.setStroke()
        fillColor.setFill()
        path.lineWidth = 3
        path.stroke()
        path.fill()
    }
    
    

}
